@@ -1,5 +1,5 @@
 from .text_preprocessor import TextPreProcessor
-from .udpipe_parser import *
+from .udpipe_parser_temp import *
 from .dicts import *
 from .utilities import *
 
